/**
 * @file
 */

(function (Drupal) {

    'use strict';

    /**
     * Registers behaviours related to Bynder field formatter.
     */
    Drupal.behaviors.BynderFormatter = {
        attach: function (context) {
          const elements = once('bynderpopper', '.bynder-wrapper');
          elements.forEach(function (element) {
            const popperAttach = element.querySelector('.bynder-image');
            const popperTooltip = element.querySelector('.bynder-tooltip');
            const popperInstance = Popper.createPopper(popperAttach, popperTooltip, {
              placement: 'top',
              modifiers: [
                {
                  name: 'offset',
                  options: {
                    offset: [0, -20],
                  },
                },
              ],
            });

            // Show/hide the tooltip.
            const showEvents = ['mouseenter', 'focus'];
            const hideEvents = ['mouseleave', 'blur'];

            showEvents.forEach((event ) => {
              element.addEventListener(event, function () {
                popperTooltip.setAttribute('data-show', '');
                popperInstance.update();
              }, popperInstance);
            });

            hideEvents.forEach((event) => {
              element.addEventListener(event, function () {
                popperTooltip.removeAttribute('data-show');
              });
            });
          });
        }
    };

}(Drupal));

